# TODO: hdfs/java
#
# Conditional build:
%bcond_with	tests		# build with tests
%bcond_with	benchmark	# enable Google Benchmark
%bcond_without	static_libs	# don't build static libraries
%bcond_without	tbb		# Threading Building Blocks support

Summary:	RocksDB: A Persistent Key-Value Store for Flash and RAM Storage
Summary(pl.UTF-8):	RocksDB - trwała baza danych klucz-wartość dla pamięci Flash i RAM
Name:		rocksdb
# NOTE: stick to 7.8.x for now; ceph 17.2.5 is not ready for rocksdb 7.10.x (or even 7.9.x?) due to cache changes
Version:	7.8.3
Release:	1
License:	BSD
Group:		Libraries
#Source0Download: https://github.com/facebook/rocksdb/releases
Source0:	https://github.com/facebook/rocksdb/archive/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	745d3b15e57e31670b5ea607c5bb82ff
Patch0:		%{name}-detect-flags.patch
Patch1:		%{name}-pc.patch
URL:		https://rocksdb.org/
BuildRequires:	bzip2-devel >= 1.0.8
BuildRequires:	gflags-devel
%{?with_benchmark:BuildRequires:	google-benchmark-devel}
# libtcmalloc also supported, but jemalloc is preferred
BuildRequires:	jemalloc-devel
%ifarch i386 i486
BuildRequires:	libatomic-devel
%endif
BuildRequires:	libstdc++-devel >= 6:4.7
BuildRequires:	liburing-devel
BuildRequires:	lz4-devel >= 1:1.9.2
BuildRequires:	numactl-devel
BuildRequires:	rpmbuild(macros) >= 1.734
BuildRequires:	snappy-devel >= 1.1.8
%{?with_tbb:BuildRequires:	tbb-devel}
BuildRequires:	zlib-devel >= 1.2.11
BuildRequires:	zstd-devel >= 1.4.4
Requires:	bzip2 >= 1.0.8
Requires:	lz4 >= 1:1.9.2
Requires:	snappy >= 1.1.8
Requires:	zlib >= 1.2.11
Requires:	zstd >= 1.4.4
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
RocksDB is a Persistent Key-Value Store for Flash and RAM Storage.

%description -l pl.UTF-8
RocksDB to trwała baza danych klucz-wartość dla pamięci Flash i RAM.

%package devel
Summary:	Header files for RocksDB library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki RocksDB
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	libstdc++-devel >= 6:4.7

%description devel
Header files for RocksDB library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki RocksDB.

%package static
Summary:	Static RocksDB library
Summary(pl.UTF-8):	Statyczna biblioteka RocksDB
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static RocksDB library.

%description static -l pl.UTF-8
Statyczna biblioteka RocksDB.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
%if %{without benchmark}
export ROCKSDB_DISABLE_BENCHMARK=1
%endif
%if %{without tbb}
export ROCKSDB_DISABLE_TBB=1
%endif

for target in %{?with_static_libs:static_lib} shared_lib tools_lib tools %{?with_tests:check} ; do
%ifarch i386 i486
PLATFORM_LDFLAGS="-latomic" \
%endif
%{__make} $target \
	AM_DEFAULT_VERBOSITY=1 \
	CC="%{__cc}" \
	CXX="%{__cxx}" \
	%{!?with_debug:DEBUG_LEVEL=0} \
	EXTRA_CFLAGS="$(pkg-config --cflags liblz4)" \
	OPT="%{rpmcflags} %{!?debug:-DNDEBUG}" \
	PORTABLE=1 \
	USE_RTTI=1 \
	WARNING_FLAGS="%{rpmcppflags} -Wall"
done

%install
rm -rf $RPM_BUILD_ROOT

%if %{without benchmark}
export ROCKSDB_DISABLE_BENCHMARK=1
%endif
%if %{without tbb}
export ROCKSDB_DISABLE_TBB=1
%endif

%{__make} install \
	%{!?with_debug:DEBUG_LEVEL=0} \
	PORTABLE=1 \
	DESTDIR=$RPM_BUILD_ROOT \
	PREFIX=%{_prefix} \
	LIBDIR=%{_libdir}

# reduntant symlink
%{__rm} $RPM_BUILD_ROOT%{_libdir}/librocksdb.so.7

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS DEFAULT_OPTIONS_HISTORY.md DUMP_FORMAT.md HISTORY.md LANGUAGE-BINDINGS.md LICENSE.leveldb README.md ROCKSDB_LITE.md USERS.md
%attr(755,root,root) %{_libdir}/librocksdb.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/librocksdb.so.7.8

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/librocksdb.so
%{_includedir}/rocksdb
%{_pkgconfigdir}/rocksdb.pc

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/librocksdb.a
%endif
%changelog
* Thu Mar 23 2023 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/rocksdb.git;a=log;h=master

* Wed Mar 22 2023 Jakub Bogusz <qboosh@pld-linux.org> 02b6e67
- updated to 7.8.3 (new soname)

* Thu Sep 15 2022 Jakub Bogusz <qboosh@pld-linux.org> 7e2f626
- request make targets sequentially, make static_lib removes shared library files

* Thu Sep 15 2022 Jakub Bogusz <qboosh@pld-linux.org> 37566e7
- debug for missing shared install on builders

* Mon Aug 22 2022 Jakub Bogusz <qboosh@pld-linux.org> 578f0ab
- updated to 6.29.5 (new soname)
- updated detect-flags patch
- removed outdated libdir,make-programs,link patches
- added pc patch (don't put build-time compiler/linker flags in .pc file)
- disable google-benchmark by default

* Thu Dec 16 2021 Jan Palus <atler@pld-linux.org> 36bc869
- tbb rebuild

* Thu Dec 16 2021 Jan Palus <atler@pld-linux.org> ea162fa
- rediff patch

* Fri May 22 2020 Jakub Bogusz <qboosh@pld-linux.org> 4eda5fd
- updated to 6.8.1 (new soname)
- added link patch

* Thu May 16 2019 Marcin Krol <hawk@tld-linux.org> e76d675
- fix make params, added USE_RTTI=1 to enable extending classes and
  prevent unresolved symbols when linking with rocksdb

* Wed May 15 2019 Jakub Bogusz <qboosh@pld-linux.org> dd1b7ce
- updated to 6.0.2 (note: new soname)
- updated libdir patch
- removed obsolete jemalloc patch

* Wed Jun 20 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> dfb5c73
- use newer rpm macros that skip checking std::__once_callable, std::__once_call

* Fri Apr 28 2017 Jakub Bogusz <qboosh@pld-linux.org> 5aa83c4
- updated to 5.2.1 (note: new soname)
- updated detect-flags patch

* Mon Dec 26 2016 Jakub Bogusz <qboosh@pld-linux.org> 4907cb5
- updated to 4.13.5
- removed obsolete numa patch
- added detect-flags, pass EXTRA_CFLAGS to fix detection of lz4 with headers in subdirectory

* Sat Sep 17 2016 Jakub Bogusz <qboosh@pld-linux.org> 2592c03
- updated to 4.9
- added jemalloc patch

* Sat Apr 09 2016 Jakub Bogusz <qboosh@pld-linux.org> d120039
- updated to 4.4.1 (note: new soname)
- added numa patch (fix libnuma detection)
- BR: numactl, zstd, jemalloc (preferred over libtcmalloc, since 3.x?)

* Tue Sep 15 2015 Jakub Bogusz <qboosh@pld-linux.org> b136638
- updated to 3.13.1 (note: soname set/changed)
- updated libdir patch

* Mon Aug 03 2015 Elan Ruusamäe <glen@delfi.ee> b427c49
- add tests and static_libs bcond. tests fail to compile

* Mon Aug 03 2015 Elan Ruusamäe <glen@delfi.ee> 83ab867
- up to 3.10.2

* Sun Feb 15 2015 Jakub Bogusz <qboosh@pld-linux.org> 8b803cb
- updated to 3.9.1

* Sat Feb 07 2015 Jakub Bogusz <qboosh@pld-linux.org> a62a018
- updated to 3.9

* Sun Dec 07 2014 Jakub Bogusz <qboosh@pld-linux.org> 0e05e9f
- updated to 3.8

